#!/usr/bin/env python
# -*- coding: utf-8 -*-
import bottle
import inspect
import beaker
from beaker import middleware


class BeakerPlugin(object):
    name = 'beaker'

    def __init__(self, keyword='beaker'):
        """
        :param keyword: Keyword used to inject beaker in a route
        """
        self.keyword = keyword

    def setup(self, app):
        """ Make sure that other installed plugins don't affect the same
            keyword argument and check if metadata is available."""
        for other in app.plugins:
            if not isinstance(other, BeakerPlugin):
                continue
            if other.keyword == self.keyword:
                raise bottle.PluginError("Found another beaker plugin "
                                         "with conflicting settings ("
                                         "non-unique keyword).")

    def apply(self, callback, context):
        args = inspect.getargspec(context['callback'])[0]

        if self.keyword not in args:
            return callback

        def wrapper(*args, **kwargs):
            kwargs[self.keyword] = beaker
            kwargs["{0}_middleware".format(self.keyword)] = middleware
            return callback(*args, **kwargs)

        return wrapper



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from setuptools import setup


description = "Bottle plugin beaker, WSGI middleware for sessions and caching"
REQUIREMENTS = [i.strip() for i in open("requirements.txt").readlines()]

setup(
    name='bottle-beaker',
    version="0.1.2",
    description=description,
    author="Thiago Avelino",
    author_email="thiago@avelino.xxx",
    license='MIT',
    platforms='any',
    zip_safe=False,
    url='https://github.com/bottlepy/bottle-beaker',
    py_modules=['bottle_beaker'],
    install_requires = REQUIREMENTS,
    requires=['bottle (>=0.9)', 'beaker'],
    classifiers=[
        'Environment :: Web Environment',
        'Environment :: Plugins',
        'Framework :: Bottle',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)
